@@ -44,7 +44,10 @@ anova.PLADMM <- function(object, ...) {
 
 }
 
-anova.PLADMMlist <- function(object) {
+#' @importFrom stats pchisq
+#' @method anova PLADMMlist
+#' @export
+anova.PLADMMlist <- function(object, ...) {
     # check validity
     n <- vapply(object, function(x) nrow(x$orderings), numeric(1))
     if (any(n != n[1]))
